@@ -9,18 +9,10 @@ from .client import ImapClient
 
 
 class ImapBackend(ConsoleEmailBackend):
-    """
-    Configuration:
-    EMAIL_IMAP_HOST: IMAP server host
-    EMAIL_IMAP_MAILBOX: destination IMAP folder (default: MAILBOX)
-    EMAIL_IMAP_USER: IMAP user
-    EMAIL_IMAP_PASSWORD: IMAP user password
-    """
-
     def __init__(self, **kwargs):
         self._clients = []
 
-        for config in getattr(settings, 'EMAIL_IMAP_MAILBOXES', []):
+        for config in getattr(settings, 'EMAIL_IMAP_SECRETS', []):
             self._clients.append(ImapClient(config))
 
         # We are going to open create stream in open() method
